@@ -21,10 +21,12 @@
 
 #include "gbp-cmake-build-system.h"
 #include "gbp-cmake-pipeline-addin.h"
+#include "gbp-cmake-toolchain-provider.h"
 
 void
 gbp_cmake_register_types (PeasObjectModule *module)
 {
   peas_object_module_register_extension_type (module, IDE_TYPE_BUILD_PIPELINE_ADDIN, GBP_TYPE_CMAKE_PIPELINE_ADDIN);
   peas_object_module_register_extension_type (module, IDE_TYPE_BUILD_SYSTEM, GBP_TYPE_CMAKE_BUILD_SYSTEM);
+  peas_object_module_register_extension_type (module, IDE_TYPE_TOOLCHAIN_PROVIDER, GBP_TYPE_CMAKE_TOOLCHAIN_PROVIDER);
 }
