@@ -51,8 +51,8 @@ static GParamSpec *properties [N_PROPS];
 static void
 install_bundle_state_free (InstallBundleState *state)
 {
-  dzl_clear_pointer (&state->local_path, g_free);
-  dzl_clear_pointer (&state->remote_path, g_free);
+  g_clear_pointer (&state->local_path, g_free);
+  g_clear_pointer (&state->remote_path, g_free);
   if (state->progress_data_destroy)
     state->progress_data_destroy (state->progress_data);
   g_slice_free (InstallBundleState, state);
@@ -627,7 +627,7 @@ gbp_deviced_device_install_bundle_async (GbpDevicedDevice      *self,
   state->progress = progress;
   state->progress_data = progress_data;
   state->progress_data_destroy = progress_data_destroy;
-  ide_task_set_task_data (task, state, (GDestroyNotify)install_bundle_state_free);
+  ide_task_set_task_data (task, state, install_bundle_state_free);
 
   gbp_deviced_device_get_client_async (self,
                                        cancellable,
